import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/Tejamod/f6296fe79c46e2bf76eb7052367e9f0b/raw/3943601b65a329d602eaf92d4d363e002072b501/gamesales.csv'
const width = 920;
const height = 522;
const margin = { top: 30, right: 30, bottom: 55, left: 180 };


const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.games = +d['Global_Sales'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 11));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 90;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map(d => d.Name))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.games)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="orange" />
              <text
              style={{ textAnchor: 'left' }}
              dy=".76em"
              y={innerHeight + 4}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
          
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.Name}
            x={0}
            y={yScale(d.Name)}
            width={xScale(d.games)}
            height={yScale.bandwidth()}
            fill='orange'
          />
        ))}
        
        
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);